function M = loadshape_minimal(shape_path,opts)



if (nargin < 2)
    opts = struct;
    opts.shuffle = false;
    opts.calcDist = true;
    opts.lumped = true;
end

% if (~isfield(opts,'K'))
%     opts.K = 200;
% end


assert(exist(shape_path,'file')==2,'shape file does not exist')

[shape_folder, name, ext] = fileparts(shape_path);

M.name = name;
switch ext
    case '.vert'
        [M.TRIV, M.VERT] = loadTosca(shape_path);
    case '.tri'
        [M.TRIV, M.VERT] = loadTosca(shape_path);
    case '.off'
        [M.TRIV, M.VERT] = loadOff(shape_path);
    case ''
        disp('No extension given, assuming TOSCA format')
        [M.TRIV, M.VERT] = loadTosca(shape_path);
    case '.ply'
        [Tri,Pts] = ply_read(shape_path,'tri');
        M.TRIV = Tri';
        M.VERT = Pts';
    otherwise
        error('Format not supportet: %s\n',ext);
end

M.n = length(M.VERT);
% opts.K = min(opts.K,M.n-1);



% Shuffling the vertices
if (isfield(opts,'shuffle') && opts.shuffle)
    perm = randperm(M.n);
    M.gt(perm) = 1:M.n;
    M.gti = perm;
    M.VERT = M.VERT(perm,:);
    M.TRIV = M.gt(M.TRIV);
else
    M.gt = 1:M.n;
    M.gti = 1:M.n;
end

% Calculate distances
if (isfield(opts,'calcDist') && opts.calcDist)
    M.Gamma = calc_dist_mat(M.VERT,M.TRIV);
    [ M.fps , M.sradius ] = metricfps_new( M.n, M.Gamma);
    % TODO: Distancematrix construction in fps order (speed up)
end

% M.k = opts.K;
M.m = length(M.TRIV);

% Bilinearforms, Laplacian decomposition
[M.M,M.S] = laplacian(M.VERT,M.TRIV);
if (isfield(opts,'lumped') && opts.lumped)
    M.M = sparse(1:M.n,1:M.n,sum(M.M));
end


% if (opts.K>0)
%     [M.phi,M.lambda] = eigs(-M.S,M.M,opts.K,1e-5);
%     M.lambda = diag(M.lambda);
%     %sort eigenvalues
%     [M.lambda,idx] = sort(M.lambda,'descend');
%     M.phi = M.phi(:,idx);
%     M.phiI = M.phi'*M.M;
% end
% 
% [M.Dc,M.fps,M.r] = compressed_distance_matrix(M.TRIV,M.VERT,M.phi,M.M,true);


% if 1 % pseudo inverse of phi (more accurate than phiI)
%     [Q,R] = qr(M.phi,0);
%     tol = abs(R(1)) * M.m * eps(class(R));
%     xrank = sum(abs(diag(R)) > tol);
%     assert(xrank==size(M.phi,2));
%     RQt = R \ Q';
%     M.phi_pinv = RQt;
% end
% % Remove
% 
% M.X = M.VERT(:,1);
% M.Y = M.VERT(:,2);
% M.Z = M.VERT(:,3);
% 
% M.Ml = sparse(1:M.n,1:M.n,sum(M.M));
% 
% rows = kron((1:M.m)',ones(3,1));
% cols = reshape(M.TRIV',3*M.m,1);
% M.proj = sparse(rows,cols,1/3,M.m,M.n);
M.area = sum(M.M(:));
% 
% M.grad = calc_gradient(M);
% 
% M.tri_areas = facearea(M.VERT,M.TRIV);
% 
end




